@@ -111,12 +111,6 @@ gpk_update_viewer_quit (void)
 	g_application_release (G_APPLICATION (application));
 }
 
-static void
-gpk_update_viewer_button_quit_cb (GtkWidget *widget, gpointer user_data)
-{
-	gpk_update_viewer_quit ();
-}
-
 static void
 gpk_update_viewer_packages_set_sensitive (gboolean sensitive)
 {
@@ -914,9 +908,6 @@ gpk_update_viewer_progress_cb (PkProgress *progress,
 
 			widget = GTK_WIDGET(gtk_builder_get_object (builder, "progressbar_progress"));
 			gtk_widget_hide (widget);
-
-			widget = GTK_WIDGET(gtk_builder_get_object (builder, "button_quit"));
-			gtk_widget_set_sensitive (widget, TRUE);
 		} else {
 			if (status == PK_STATUS_ENUM_QUERY || status == PK_STATUS_ENUM_SETUP) {
 				/* TRANSLATORS: querying update array */
@@ -983,15 +974,6 @@ gpk_update_viewer_progress_cb (PkProgress *progress,
 					    -1);
 		}
 		gtk_tree_path_free (path);
-
-	} else if (type == PK_PROGRESS_TYPE_ALLOW_CANCEL) {
-		gboolean idle;
-		widget = GTK_WIDGET(gtk_builder_get_object (builder, "button_quit"));
-
-		/* we have to also check for idle as we might be getting the AllowCancel(false)
-		 * signal _after_ the PkClient has been marked as idle */
-		g_object_get (task, "idle", &idle, NULL);
-		gtk_widget_set_sensitive (widget, (allow_cancel || idle));
 	}
 }
 
@@ -999,16 +981,10 @@ static void
 gpk_update_viewer_client_notify_idle_cb (PkClient *client, GParamSpec *pspec, gpointer user_data)
 {
 	gboolean idle;
-	GtkWidget *widget;
-
 	g_object_get (client,
 		      "idle", &idle,
 		      NULL);
-	/* ensure button is sensitive */
-	if (idle) {
-		widget = GTK_WIDGET(gtk_builder_get_object (builder, "button_quit"));
-		gtk_widget_set_sensitive (widget, TRUE);
-	}
+	g_debug ("client is idle: %i", idle);
 }
 
 static gboolean
@@ -1281,7 +1257,7 @@ static void
 gpk_update_viewer_reconsider_info (void)
 {
 	GtkWidget *widget;
-	guint len;
+	guint len = 0;
 	const gchar *title;
 	g_autofree gchar *text_total = NULL;
 	g_autofree gchar *text_markup = NULL;
@@ -1357,39 +1333,36 @@ gpk_update_viewer_reconsider_info (void)
 
 	/* header */
 	widget = GTK_WIDGET(gtk_builder_get_object (builder, "label_header_title"));
-	text_total = g_strdup_printf (ngettext ("There is %i update available",
-						"There are %i updates available", len), len);
+	text_total = g_strdup_printf (ngettext ("There is %u update available",
+						"There are %u updates available", len), len);
 	text_markup = g_strdup_printf ("<big><b>%s</b></big>", text_total);
 	gtk_label_set_label (GTK_LABEL(widget), text_markup);
 	widget = GTK_WIDGET(gtk_builder_get_object (builder, "hbox_header"));
 	gtk_widget_show (widget);
 
 	/* total */
-	widget = GTK_WIDGET(gtk_builder_get_object (builder, "label_summary"));
+	widget = GTK_WIDGET(gtk_builder_get_object (builder, "headerbar"));
 	if (number_total == 0) {
-		gtk_label_set_label (GTK_LABEL(widget), "");
+		gtk_header_bar_set_subtitle (GTK_HEADER_BAR(widget), NULL);
 	} else {
 		if (size_total == 0) {
 			g_autofree gchar *text = NULL;
 			/* TRANSLATORS: how many updates are selected in the UI */
-			text = g_strdup_printf (ngettext ("%i update selected",
-							  "%i updates selected",
+			text = g_strdup_printf (ngettext ("%u update selected",
+							  "%u updates selected",
 							  number_total), number_total);
-			gtk_label_set_label (GTK_LABEL(widget), text);
+			gtk_header_bar_set_subtitle (GTK_HEADER_BAR(widget), text);
 		} else {
 			g_autofree gchar *text = NULL;
 			g_autofree gchar *text_size = NULL;
 			text_size = g_format_size (size_total);
 			/* TRANSLATORS: how many updates are selected in the UI, and the size of packages to download */
-			text = g_strdup_printf (ngettext ("%i update selected (%s)",
-							  "%i updates selected (%s)",
+			text = g_strdup_printf (ngettext ("%u update selected (%s)",
+							  "%u updates selected (%s)",
 							  number_total), number_total, text_size);
-			gtk_label_set_label (GTK_LABEL(widget), text);
+			gtk_header_bar_set_subtitle (GTK_HEADER_BAR(widget), text);
 		}
 	}
-
-	widget = GTK_WIDGET(gtk_builder_get_object (builder, "label_summary"));
-	gtk_widget_show (widget);
 out:
 	gpk_update_viewer_check_mobile_broadband ();
 }
@@ -2805,7 +2778,9 @@ gpk_update_viewer_application_startup_cb (GtkApplication *_application, gpointer
 
 	/* get UI */
 	builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-update-viewer.ui", &error);
+	retval = gtk_builder_add_from_resource (builder,
+						"/org/gnome/packagekit/gpk-update-viewer.ui",
+						&error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
 		return;
@@ -2867,8 +2842,6 @@ gpk_update_viewer_application_startup_cb (GtkApplication *_application, gpointer
 	/* bottom UI */
 	widget = GTK_WIDGET(gtk_builder_get_object (builder, "progressbar_progress"));
 	gtk_widget_hide (widget);
-	widget = GTK_WIDGET(gtk_builder_get_object (builder, "label_summary"));
-	gtk_widget_hide (widget);
 
 	/* set install button insensitive */
 	widget = GTK_WIDGET(gtk_builder_get_object (builder, "button_install"));
@@ -2882,12 +2855,6 @@ gpk_update_viewer_application_startup_cb (GtkApplication *_application, gpointer
 	widget = GTK_WIDGET(gtk_builder_get_object (builder, "scrolledwindow_details"));
 	gtk_widget_set_sensitive (widget, FALSE);
 
-	/* close button */
-	widget = GTK_WIDGET(gtk_builder_get_object (builder, "button_quit"));
-	g_signal_connect (widget, "clicked",
-			  G_CALLBACK (gpk_update_viewer_button_quit_cb), NULL);
-	gtk_window_set_focus (GTK_WINDOW(main_window), widget);
-
 	/* upgrade button */
 	widget = GTK_WIDGET(gtk_builder_get_object (builder, "button_upgrade"));
 	g_signal_connect (widget, "clicked",
